@@ -2,15 +2,12 @@
 import os
 import sys
 import logging
+from importlib import import_module
 from argparse import ArgumentParser
 
 from exonutils.webapp.server import SimpleWebServer
 from exonutils.webapp.extserver import ExtWebServer, WebArbiter
 
-from exonwebui import __file__ as exonwebui_path
-from exonwebui.utils.locale import init_locale
-from exonwebui.utils.gzip import init_gzip
-
 logging.basicConfig(
     level=logging.INFO, stream=sys.stdout,
     format='%(asctime)s %(levelname)-5.5s [%(name)s] %(message)s')
@@ -21,6 +18,8 @@ logging.addLevelName(logging.CRITICAL, "FATAL")
 HOST = "0.0.0.0"
 PORT = 8000
 
+CDN_URL = 'https://cdn.jsdelivr.net/gh/exonlabs/exonwebui-static@1.0/pool'
+
 APP_OPTIONS = {
     'secret_key': "0123456789ABCDEF",
     'max_content_length': 10485760,  # 10MiB
@@ -35,6 +34,8 @@ EXT_OPTIONS = {
     'timeout': 0,
 }
 
+BASE_PATH = os.path.abspath(os.path.dirname(__file__))
+
 
 def init_app(websrv, args):
     # disable strict slash matching
@@ -48,14 +49,29 @@ def init_app(websrv, args):
     websrv.app.config['CSRF_DISABLE'] = True
 
     # adjust locale
+    from exonwebui.utils.locale import init_locale
     locale_path = os.path.join(websrv.base_path, 'locale')
     init_locale(websrv.app, locale_path=locale_path)
 
     # adjust gzip
     if args.ext_gzip:
+        from exonwebui.utils.gzip import init_gzip
         init_gzip(websrv.app)
 
 
+def cleanup():
+    # clean exonwebui resources links
+    for n in ['templates', 'static']:
+        link_path = os.path.join(BASE_PATH, n, 'webui')
+        if os.path.exists(link_path):  # or os.path.islink(link_path):
+            os.unlink(link_path)
+
+    # clean exonwebui_static vendor resources link
+    link_path = os.path.join(BASE_PATH, 'static', 'vendor')
+    if os.path.exists(link_path):  # or os.path.islink(link_path):
+        os.unlink(link_path)
+
+
 def main():
     logger = logging.getLogger()
     logger.name = 'main'
@@ -75,6 +91,9 @@ def main():
         pr.add_argument(
             '--ext-gzip', dest='ext_gzip', action='store_true',
             help="use extended gzip compression module")
+        pr.add_argument(
+            '--use-cdn', dest='use_cdn', action='store_true',
+            help="enable use of cdn for static contents")
         args = pr.parse_args()
 
         if args.debug > 0:
@@ -82,21 +101,31 @@ def main():
         if args.debug >= 3:
             APP_OPTIONS['templates_auto_reload'] = True
 
-        # adjust resources links
-        base_path = os.path.abspath(os.path.dirname(__file__))
+        # set templates CDN url
+        if args.use_cdn:
+            APP_OPTIONS['TPL_CDN_URL'] = CDN_URL
+
+        cleanup()
+
+        # adjust exonwebui resources links
+        root_srcpath = import_module('exonwebui').__path__[0]
         for n in ['templates', 'static']:
-            link_path = os.path.join(base_path, n, 'webui')
-            if os.path.isfile(link_path) or os.path.islink(link_path):
-                os.unlink(link_path)
-            src_dir = os.path.join(
-                os.path.dirname(exonwebui_path), n)
+            src_dir = os.path.join(root_srcpath, n)
             if os.path.exists(src_dir):
+                link_path = os.path.join(BASE_PATH, n, 'webui')
                 os.symlink(src_dir, link_path)
 
+        # adjust exonwebui_static vendor resources link
+        root_srcpath = import_module('exonwebui_static').__path__[0]
+        if os.path.exists(root_srcpath):
+            link_path = os.path.join(BASE_PATH, 'static', 'vendor')
+            os.symlink(root_srcpath, link_path)
+
+        # create web server handler
         websrv = SimpleWebServer(
             name='WebUiPortal', options=APP_OPTIONS,
             logger=logger, reqlogger=reqlog)
-        websrv.base_path = base_path
+        websrv.base_path = BASE_PATH
         websrv.initialize()
 
         init_app(websrv, args)
@@ -117,6 +146,8 @@ def main():
     except Exception as e:
         logger.fatal(str(e), exc_info=args.debug)
         sys.exit(1)
+    finally:
+        cleanup()
 
 
 if __name__ == '__main__':
