@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 import time
 from random import randint
-from flask import session, flash, request, url_for, render_template as tpl
+from flask import current_app, session, flash, request, \
+    url_for, render_template as tpl
 from flask_babelex import gettext, lazy_gettext
 
 from exonutils.buffers.filebuffer import SimpleFileBuffer
@@ -24,9 +25,11 @@ class Index(MenuBoardView):
         global MENU_BUFFER
 
         params = {
+            'doc_title': "WebUI",
             'doc_lang': session.get('lang', ''),
             'doc_langdir': session.get('lang_dir', ''),
-            'doc_title': "WebUI",
+            'langs': current_app.config['LOCALE_LANGS'],
+            'cdn_url': current_app.config.get('TPL_CDN_URL'),
             'menu': MENU_BUFFER,
         }
 
@@ -37,9 +40,9 @@ class Index(MenuBoardView):
             return self.redirect(url_for('index'))
 
         if session.get('simpleboard', False):
-            return tpl('simpleboard.min.tpl', **params)
+            return tpl('simpleboard.min.j2', **params)
         else:
-            return tpl('mainboard.min.tpl', **params)
+            return tpl('mainboard.min.j2', **params)
 
 
 class Home(MenuBoardView):
@@ -52,7 +55,11 @@ class Home(MenuBoardView):
             lazy_gettext('Home'), icon='fa-home', url='#home')
 
     def get(self, **kwargs):
-        html = tpl('option_panel.min.tpl', message=gettext("Welcome"))
+        params = {
+            'langs': current_app.config['LOCALE_LANGS'],
+            'message': gettext("Welcome"),
+        }
+        html = tpl('option_panel.min.j2', **params)
         return self.reply(html, doctitle=gettext('Home'))
 
 
@@ -67,12 +74,13 @@ class Notify(MenuBoardView):
 
     def get(self, **kwargs):
         from exonwebui.macros.basic import UiAlert
-        flash(gettext('error') + " STICKY_MSG", 'error.us')
-        flash(gettext('warning'), 'warn')
-        flash(gettext('info'), 'info')
-        flash(gettext('success'), 'success')
-        html = UiAlert('message', gettext('showing notifications'),
+        flash(gettext('error message') + " STICKY_MSG", 'error.us')
+        flash(gettext('warning message'), 'warn')
+        flash(gettext('info message'), 'info')
+        flash(gettext('success message'), 'success')
+        html = UiAlert('general message', gettext('showing notifications'),
                        styles='p-3', dismiss=False)
+        html += '<script>WebUI.board_menu.show_submenu(1)</script>'
         return self.reply(html, doctitle=gettext('Notifications'))
 
 
@@ -87,11 +95,12 @@ class Alerts(MenuBoardView):
 
     def get(self, **kwargs):
         from exonwebui.macros.basic import UiAlert
-        html = UiAlert('info', gettext('info'), styles='px-3 pt-3')
-        html += UiAlert('warn', gettext('warning'), styles='px-3')
-        html += UiAlert('error', gettext('error'), styles='px-3')
-        html += UiAlert('success', gettext('success'), styles='px-3')
-        html += UiAlert('message', gettext('message'), styles='px-3')
+        html = UiAlert('info', gettext('info message'), styles='px-3 pt-3')
+        html += UiAlert('warn', gettext('warning message'), styles='px-3')
+        html += UiAlert('error', gettext('error message'), styles='px-3')
+        html += UiAlert('success', gettext('success message'), styles='px-3')
+        html += UiAlert('message', gettext('general message'), styles='px-3')
+        html += '<script>WebUI.board_menu.show_submenu(1)</script>'
         return self.reply(html, doctitle=gettext('Alerts'))
 
 
@@ -109,6 +118,7 @@ class InputForm(MenuBoardView):
         options = {
             'form_id': "1234",
             'submit_url': "/inputform",
+            'cdn_url': current_app.config.get('TPL_CDN_URL'),
             'fields': [
                 {'type': 'checkbox', 'label': gettext('Validation'),
                  'options': [{'label': gettext('Server side validation'),
@@ -202,7 +212,8 @@ class InputForm(MenuBoardView):
                  'helpguide': gettext("Extra detailed long help for fields")},
             ]
         }
-        html = tpl('input_form.min.tpl', contents=UiInputForm(options))
+        html = tpl('input_form.min.j2', contents=UiInputForm(options))
+        html += '<script>WebUI.board_menu.show_submenu(1)</script>'
         return self.reply(html, doctitle=gettext('Input Form'))
 
     def post(self, **kwargs):
@@ -246,6 +257,7 @@ class Datagrid(MenuBoardView):
             'grid_id': "1234",
             'base_url': "/datagrid",
             'load_url': "/datagrid/loaddata",
+            'cdn_url': current_app.config.get('TPL_CDN_URL'),
             'length_menu': [10, 50, 100, 250, -1],
             'columns': [
                 {'id': 'field1', 'title': "Field Name 1"},
@@ -283,7 +295,8 @@ class Datagrid(MenuBoardView):
                 {'label': 'Op 3 with Reload', 'action': "group_op3"},
             ],
         }
-        html = tpl('data_grid.min.tpl', contents=UiStdDataGrid(options))
+        html = tpl('data_grid.min.j2', contents=UiStdDataGrid(options))
+        html += '<script>WebUI.board_menu.show_submenu(1)</script>'
         return self.reply(html, doctitle=gettext('Datagrid'))
 
     def post(self, **kwargs):
@@ -324,7 +337,7 @@ class Datagrid(MenuBoardView):
 
         if action in ['single_op1', 'single_op2',
                       'group_op1', 'group_op2', 'group_op3']:
-            rows = request.form.getlist('rows[]')
+            rows = request.form.getlist('items[]')
             if len(rows) > 20:
                 rows = rows[:21]
                 rows[20] = '...'
@@ -355,6 +368,7 @@ class QueryBuilder(MenuBoardView):
         from exonwebui.macros.forms import UiQBuilder
         options = {
             'form_id': "1234",
+            'cdn_url': current_app.config.get('TPL_CDN_URL'),
             'filters': [
                 {'id': 'field1', 'label': 'Field 1', 'type': 'string',
                  'operators': ['equal', 'not_equal', 'contains']},
@@ -407,7 +421,8 @@ class QueryBuilder(MenuBoardView):
                 ],
             },
         }
-        html = tpl('query_builder.min.tpl', contents=UiQBuilder(options))
+        html = tpl('query_builder.min.j2', contents=UiQBuilder(options))
+        html += '<script>WebUI.board_menu.show_submenu(1)</script>'
         return self.reply(html, doctitle=gettext('Query Builder'))
 
 
@@ -425,7 +440,7 @@ class Loader(MenuBoardView):
         from exonwebui.macros.basic import UiAlert
         html = UiAlert('message', gettext('loaded after delay'),
                        styles='p-3', dismiss=False)
-        html += tpl('progress_loader.min.tpl')
+        html += tpl('progress_loader.min.j2')
 
         # simulate delay
         time.sleep(3)
@@ -467,18 +482,22 @@ class Loginpage(MenuBoardView):
         action = kwargs.get('action') or ''
 
         if action == 'load':
-            html = UiLoginForm(
-                {'submit_url': url_for('loginpage'), 'authkey': '123456'},
-                styles="text-white bg-secondary")
+            html = UiLoginForm({
+                'cdn_url': current_app.config.get('TPL_CDN_URL'),
+                'submit_url': url_for('loginpage'),
+                'authkey': '123456',
+            }, styles="text-white bg-secondary")
             return self.reply(html, doctitle=gettext('Loginpage'))
         else:
             params = {
+                'doc_title': "WebUI",
                 'doc_lang': session.get('lang', ''),
                 'doc_langdir': session.get('lang_dir', ''),
-                'doc_title': "WebUI",
+                'langs': current_app.config['LOCALE_LANGS'],
+                'cdn_url': current_app.config.get('TPL_CDN_URL'),
                 'load_url': "%s/load" % url_for('loginpage'),
             }
-            return tpl('loginpage.min.tpl', **params)
+            return tpl('loginpage.min.j2', **params)
 
     def post(self, **kwargs):
         username = request.form.get('username', '')
