@@ -10,7 +10,7 @@ class UiDataGridsMacro(UiBaseMacro):
 
 
 class UiStdDataGrid(UiDataGridsMacro):
-    tpl_name = 'stddatagrid.min.tpl'
+    tpl_name = 'stddatagrid.min.j2'
 
     std_render = {'_': '_', 'display': 'd'}
 
@@ -43,6 +43,7 @@ class UiStdDataGrid(UiDataGridsMacro):
             'id': options.get('grid_id', cls.randint()),
             'baseurl': options.get('base_url', ''),
             'loadurl': options.get('load_url', ''),
+            'cdn_url': options.get('cdn_url') or '',
             'lenMenu': options.get('length_menu', [25, 50, 100, -1]),
             'columns': ','.join(columns),
             'order': json.dumps(options.get('order', [2, 'asc'])),
