@@ -10,7 +10,7 @@ class UiFormsMacro(UiBaseMacro):
 
 
 class UiInputForm(UiFormsMacro):
-    tpl_name = 'inputform.min.tpl'
+    tpl_name = 'inputform.min.j2'
 
     def __new__(cls, options, styles=''):
         fields = []
@@ -30,22 +30,23 @@ class UiInputForm(UiFormsMacro):
                 'required': k.get('required', False),
                 'confirm': k.get('confirm', False),
                 'strength': k.get('strength', False),
-                'help': k.get('help', ''),
-                'helpguide': k.get('helpguide', ''),
+                'help': k.get('help') or '',
+                'helpguide': k.get('helpguide') or '',
                 'prepend': k.get('prepend', []),
                 'append': k.get('append', []),
             })
         return cls.tpl(**{
             'id': options.get('form_id', cls.randint()),
-            'submit_url': options.get('submit_url', ''),
+            'submit_url': options.get('submit_url') or '',
+            'cdn_url': options.get('cdn_url') or '',
             'fields': fields,
             'styles': styles,
-            'jscript': options.get('jscript', ''),
+            'jscript': options.get('jscript') or '',
         })
 
 
 class UiQBuilder(UiFormsMacro):
-    tpl_name = 'qbuilder.min.tpl'
+    tpl_name = 'qbuilder.min.j2'
 
     def __new__(cls, options, styles=''):
         filters = []
@@ -65,6 +66,7 @@ class UiQBuilder(UiFormsMacro):
             }))
         return cls.tpl(**{
             'id': options.get('form_id', cls.randint()),
+            'cdn_url': options.get('cdn_url') or '',
             'filters': ','.join(filters),
             'rules': json.dumps(options.get('initial_rules', None)),
             'allow_groups': options.get('allow_groups', '1'),
@@ -76,13 +78,14 @@ class UiQBuilder(UiFormsMacro):
 
 
 class UiLoginForm(UiFormsMacro):
-    tpl_name = 'loginform.min.tpl'
+    tpl_name = 'loginform.min.j2'
 
     def __new__(cls, options, styles=''):
         return cls.tpl(**{
             'id': options.get('form_id', cls.randint()),
-            'submit_url': options.get('submit_url', ''),
-            'authkey': options.get('authkey', ''),
+            'submit_url': options.get('submit_url') or '',
+            'cdn_url': options.get('cdn_url') or '',
+            'authkey': options.get('authkey') or '',
             'btn_style': options.get('btn_style', 'btn-primary'),
             'styles': styles,
         })
